from cpl_core.configuration import ConfigurationABC
from cpl_core.dependency_injection import ServiceCollectionABC
from cpl_core.environment import ApplicationEnvironmentABC
from cpl_discord.discord_event_types_enum import DiscordEventTypesEnum
from cpl_discord.service.discord_collection_abc import DiscordCollectionABC

from bot_core.abc.client_utils_service_abc import ClientUtilsServiceABC
from bot_core.abc.message_service_abc import MessageServiceABC
from bot_core.abc.module_abc import ModuleABC
from bot_core.configuration.feature_flags_enum import FeatureFlagsEnum
from bot_core.events.core_on_ready_event import CoreOnReadyEvent
from bot_core.pipes.date_time_offset_pipe import DateTimeOffsetPipe
from bot_core.service.client_utils_service import ClientUtilsService
from bot_core.service.message_service import MessageService


class CoreModule(ModuleABC):

    def __init__(self, dc: DiscordCollectionABC):
        ModuleABC.__init__(self, dc, FeatureFlagsEnum.core_module)

    def configure_configuration(self, config: ConfigurationABC, env: ApplicationEnvironmentABC):
        pass

    def configure_services(self, services: ServiceCollectionABC, env: ApplicationEnvironmentABC):
        services.add_transient(MessageServiceABC, MessageService)
        services.add_transient(ClientUtilsServiceABC, ClientUtilsService)

        # pipes
        services.add_transient(DateTimeOffsetPipe)

        self._dc.add_event(DiscordEventTypesEnum.on_ready.value, CoreOnReadyEvent)
